@@ -7,9 +7,9 @@
 #' 
 #' @param object \code{hclust | dist | data.frame}.
 #' @param data \code{data.frame}, data.frame with data. Only for \code{hclust} or \code{dist} object.
-#' @param main Title. See \link{visNetwork}
-#' @param submain Subtitle. See \link{visNetwork}
-#' @param footer Footer. See \link{visNetwork}
+#' @param main Title. See  \link[visNetwork]{visNetwork}
+#' @param submain Subtitle. See  \link[visNetwork]{visNetwork}
+#' @param footer Footer. See  \link[visNetwork]{visNetwork}
 #' @param distColumns \code{numeric}, indice of columns used for compute distance. 
 #'  If \code{NULL} (default), keep all \code{numeric} and \code{integer} columns. 
 #'  If Not \code{NULL}, keep only  \code{numeric} and \code{integer} columns
@@ -20,8 +20,8 @@
 #' So, we add boxplot / pie focus on sub-population vs all population using \code{sparkline} package. \code{NULL} to disable.
 #' @param colorEdges \code{character}, color of edges. Default to 'black'.
 #' @param colorGroups \code{character}, color for group in hexa ("#00FF00"). Default rainbow.
-#' @param minNodeSize \code{numeric}, in case of \code{nodesPopSize}, minimum size of a node. Defaut to 50. Else \code{minNodeSize + maxNodeSize / 2}. 
-#' @param maxNodeSize \code{numeric}, in case of \code{nodesPopSize}, maximum size of a node. Defaut to 200. Else \code{ minNodeSize + maxNodeSize / 2}. 
+#' @param minNodeSize \code{numeric}, in case of \code{nodesPopSize}, minimum size of a node. Default to 50. Else \code{minNodeSize + maxNodeSize / 2}. 
+#' @param maxNodeSize \code{numeric}, in case of \code{nodesPopSize}, maximum size of a node. Default to 200. Else \code{ minNodeSize + maxNodeSize / 2}. 
 #' @param nodesPopSize \code{boolean}, nodes sizes depends on population ? Default to \code{TRUE}.
 #' @param highlightNearest \code{boolean}, highlight sub-tree on click ? Default to \code{TRUE}.
 #' @param horizontal \code{boolean}, default to FALSE
@@ -216,6 +216,7 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
                              nodesPopSize = TRUE,
                              height = "600px", width = "100%", export = TRUE, ...){
   
+
   if(!is.null(data)){
     if(length(object$order)!=nrow(data)){
       stop("object and data mush contain same number of individuals")
@@ -260,7 +261,8 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
   
   dta <- toVisNetworkData(ig, idToLabel = FALSE)
   
-  dta <- lapply(dta, data.frame)
+  dta <- lapply(dta, data.frame, stringsAsFactors = FALSE)
+  dta$nodes$label <- as.character(dta$nodes$label)
   
   dta$nodes$labelComplete <- ""
   dta$nodes$neib <- I(neig)
@@ -273,9 +275,9 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
     dataNum <- dataNum[,names(dataNum)%in%drawNames, drop = FALSE]
     
     if(ncol(dataNum) > 0){
-      minPop <- apply(dataNum, 2, min)
-      maxPop <- apply(dataNum, 2, max)
-      meanPop <- colMeans(dataNum)
+      minPop <- apply(dataNum, 2, min, na.rm = T)
+      maxPop <- apply(dataNum, 2, max, na.rm = T)
+      meanPop <- colMeans(dataNum, na.rm = TRUE)
       popSpkl <- apply(dataNum,2, function(X){
         .addSparkLineOnlyJs(X, type = "box")
       })
@@ -326,7 +328,14 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
   
   tmp_layout <- suppressMessages(ggraph::create_layout(hcl, "dendrogram"))
   
-  dta$nodes$label <- tmp_layout$label
+  if(".ggraph.orig_index" %in% colnames(tmp_layout)){
+    tmp_layout <- tmp_layout[order(tmp_layout$.ggraph.orig_index),]
+    tmp_layout$ggraph.index <- tmp_layout$`.ggraph.orig_index`
+  }
+  if("height" %in% colnames(tmp_layout)){
+    tmp_layout$y <- tmp_layout$height
+  }
+  dta$nodes$label <- as.character(tmp_layout$label)
   dta$nodes$x <- tmp_layout$x
   dta$nodes$y <- tmp_layout$y
   dta$nodes$ggraph.index <- tmp_layout$ggraph.index
@@ -416,7 +425,7 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
   if(!is.null(drawNames)){
     titleDetails <-  paste0(
       '<hr class = "rPartvisNetwork">
-        <div class ="showOnMe2"><div style="text-align:center;"><U style="color:blue;" class = "classActivePointer">Details : </U></div>
+        <div class ="showOnMe2"><div style="text-align:center;"><U style="color:blue;" onmouseover="this.style.cursor=\'pointer\';" onmouseout="this.style.cursor=\'default\';">Details : </U></div>
         <div class="showMeRpartTTp2" style="display:none;margin-top: -15px">
         ', dta$nodes$labelComplete,
       '</script>',
@@ -439,7 +448,7 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
 
 .giveLabelsFromDf <- function(df, popSpkl = NULL, minPop = NULL, maxPop = NULL, meanPop = NULL){
   df <- df[!is.na(df[,1]),, drop = FALSE]
-  clM <- colMeans(df)
+  clM <- colMeans(df, na.rm = TRUE)
   if(!is.null(popSpkl)){
     nm <- names(df)
     re <- list()
@@ -463,6 +472,7 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
     tbl <- table(df[,i])
     tbl <- tbl[na.omit(match(namOrder[[i]], names(tbl)))]
     tbl <- data.frame(tbl)
+    colnames(tbl) <- "Var1"
     newMod <- namOrder[[i]][!namOrder[[i]]%in%tbl$Var1]
     if(length(newMod) > 0){
       tbl <- rbind(tbl, data.frame(Var1 = newMod, Freq = 0))
@@ -481,8 +491,8 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
 
 
 .addSparkLine <- function(vect, min = NULL, max = NULL, type = "line", labels = NULL){
-  if(is.null(min))min <- min(vect)
-  if(is.null(max))max <- max(vect)
+  if(is.null(min)) min <- min(vect, na.rm = T)
+  if(is.null(max)) max <- max(vect, na.rm = T)
   drun <- c(sample(LETTERS, 10, replace = TRUE), sample(1:1000, 5))
   drun <- paste0(drun, collapse = "")
   if(!is.null(labels)){
@@ -622,6 +632,11 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
   
   res$nodes$label <- as.character(res$nodes$label)
   
+  res$nodes$group[res$nodes$hidden] <- "hidden"
+  res$nodes$title[res$nodes$hidden] <- NA
+  res$nodes$value[res$nodes$hidden] <- 0
+  res$nodes$hidden <- NULL
+  
   # res$nodes$label[res$nodes$group %in% "individual" & res$nodes$hidden == FALSE] <- gsub("^(\\n)|(\\n)$", "", 
   # gsub("", "\\\n", res$nodes$label[res$nodes$group %in% "individual" & res$nodes$hidden == FALSE]))
   if(!horizontal){
@@ -635,6 +650,7 @@ visHclust.hclust <- function(object, data = NULL, main = "", submain = "", foote
     visGroups(groupname = "group", 
               color = list(background = "#D8D8D8", border = "black", 
                            highlight = "black", hover = "black"), shape = "square") %>%
+    visGroups(groupname = "hidden", color = "rgba(200,200,200,0)", shape = "dot") %>%
     visInteraction(hover = TRUE)
   
   if(!horizontal){
