@@ -1,25 +1,25 @@
 #' Network visualization
 #'
-#' Network visualization using vis.js library. For full documentation, have a look at \link{visDocumentation}.
+#' Network visualization using vis.js library. For full documentation, have a look at  \link[visNetwork]{visDocumentation}.
 #'
-#' @param nodes : data.frame or a list with nodes informations. Needed at least column "id". See \link{visNodes} 
+#' @param nodes : data.frame or a list with nodes informations. Needed at least column "id". See  \link[visNetwork]{visNodes} 
 #' \itemize{
-#'  \item{"id"}{ : id of the node, needed in edges information}
-#'  \item{"label"}{ : label of the node}
-#'  \item{"group"}{ : group of the node. Groups can be configure with \link{visGroups}}
-#'  \item{"value"}{ : size of the node}
-#'  \item{"title"}{ : tooltip of the node}
-#'  \item{...}{}
+#'  \item "id" id of the node, needed in edges information
+#'  \item "label" label of the node
+#'  \item "group" group of the node. Groups can be configure with  \link[visNetwork]{visGroups}
+#'  \item "value" size of the node
+#'  \item "title" tooltip of the node
+#'  \item ...
 #'}
 #'
-#' @param edges : data.frame or a list  with edges informations. Needed at least columns "from" and "to". See \link{visEdges}
+#' @param edges : data.frame or a list  with edges informations. Needed at least columns "from" and "to". See  \link[visNetwork]{visEdges}
 #' \itemize{
-#'  \item{"from"}{ : node id of begin of the edge}
-#'  \item{"to"}{ : node id of end of the edge}
-#'  \item{"label"}{ : label of the edge}
-#'  \item{"value"}{ : size of the node}
-#'  \item{"title"}{ : tooltip of the node}
-#'  \item{...}{}
+#'  \item "from" node id of begin of the edge
+#'  \item "to" node id of end of the edge
+#'  \item "label" label of the edge
+#'  \item "value" size of the node
+#'  \item "title" tooltip of the node
+#'  \item ...
 #'}
 #'
 #' @param dot : Character DOT language.
@@ -32,20 +32,20 @@
 #' 
 #'@param main : For add a title. Character or a named list.
 #'\itemize{
-#'  \item{"text"}{ : Character. Title.}
-#'  \item{"style"}{ : Optional. Character. HTML style of title. Default to 'font-family:Georgia, Times New Roman, Times, serif;font-weight:bold;font-size:20px;text-align:center;'.}
+#'  \item "text" Character. Title.
+#'  \item "style" Optional. Character. HTML style of title. Default to 'font-family:Georgia, Times New Roman, Times, serif;font-weight:bold;font-size:20px;text-align:center;'.
 #'}
 #'
 #'@param submain : For add a subtitle. Character or a named list.
 #'\itemize{
-#'  \item{"text"}{ : Character. Subtitle.}
-#'  \item{"style"}{ : Optional. Character. HTML style of submain. Default to 'font-family:Georgia, Times New Roman, Times, serif;font-size:12px;text-align:center;'.}
+#'  \item "text" Character. Subtitle.
+#'  \item "style" Optional. Character. HTML style of submain. Default to 'font-family:Georgia, Times New Roman, Times, serif;font-size:12px;text-align:center;'.
 #'}
 #'
 #'@param footer : For add a footer. Character or a named list.
 #'\itemize{
-#'  \item{"text"}{ : Character. footer.}
-#'  \item{"style"}{ : Optional. Character. HTML style of footer. Default to 'font-family:Georgia, Times New Roman, Times, serif;font-size:12px;text-align:center;'.}
+#'  \item "text" Character. footer.
+#'  \item "style" Optional. Character. HTML style of footer. Default to 'font-family:Georgia, Times New Roman, Times, serif;font-size:12px;text-align:center;'.
 #'}
 #'
 #'@param background : Background color. Default to 'rgba(0, 0, 0, 0)' (transparent). Can be a valid color name ("red"), a HEX value ("#ff0000") or rgb/rgba ("rgb(255,0,0)")
@@ -60,6 +60,7 @@
 #'
 #' visNetwork(nodes, edges)
 #'
+#' \dontrun{
 #' # add a title
 #' visNetwork(nodes, edges, main = "visNetwork minimal example")
 #' visNetwork(nodes, edges, main = list(text = "visNetwork minimal example",
@@ -147,7 +148,6 @@
 #'
 #' # use fontAwesome icons using groups or nodes options 
 #' # font-awesome is not part of dependencies. use addFontAwesome() if needed
-#' # http://fortawesome.github.io/Font-Awesome
 #' 
 #' nodes <- data.frame(id = 1:3, group = c("B", "A", "B"))
 #' edges <- data.frame(from = c(1,2), to = c(2,3))
@@ -165,7 +165,7 @@
 #'   addFontAwesome()
 #'
 #' # Save a network
-#' \dontrun{
+#' 
 #' network <- visNetwork(nodes, edges) %>% 
 #'  visOptions(highlightNearest = TRUE, nodesIdSelection = TRUE,
 #'  manipulation = TRUE) %>% visLegend()
@@ -173,19 +173,18 @@
 #' network %>% visSave(file = "network.html")
 #' # same as
 #' visSave(network, file = "network.html")
-#' }
+#' 
 #' 
 #' # Export as png/jpeg (shiny or browser only)
-#' \dontrun{
 #' visNetwork(nodes, edges) %>% 
 #'  visExport()
-#' }
+#' 
 #' 
 #' # DOT language
 #' visNetwork(dot = 'dinetwork {1 -> 1 -> 2; 2 -> 3; 2 -- 4; 2 -> 1 }')
 #' 
 #' # gephi json file
-#' \dontrun{
+#' 
 #' visNetwork(gephi = 'WorldCup2014.json') %>% visPhysics(stabilization = FALSE,   barnesHut = list(
 #'     gravitationalConstant = -10000,
 #'     springConstant = 0.002,
@@ -193,18 +192,18 @@
 #'   ))
 #'}
 #' 
-#'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
-#'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
-#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visNetworkProxy} for play with network using shiny,
-#'\link{visTree} to visualize CART rpart tree, \link{visNetworkEditor} to edit your network, 
-#'\link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
+#'@seealso  \link[visNetwork]{visNodes} for nodes options,  \link[visNetwork]{visEdges} for edges options,  \link[visNetwork]{visGroups} for groups options, 
+#' \link[visNetwork]{visLegend} for adding legend,  \link[visNetwork]{visOptions} for custom option,  \link[visNetwork]{visLayout} &  \link[visNetwork]{visHierarchicalLayout} for layout, 
+#' \link[visNetwork]{visPhysics} for control physics,  \link[visNetwork]{visInteraction} for interaction,  \link[visNetwork]{visNetworkProxy} for play with network using shiny,
+#' \link[visNetwork]{visTree} to visualize CART rpart tree,  \link[visNetwork]{visNetworkEditor} to edit your network, 
+#' \link[visNetwork]{visDocumentation},  \link[visNetwork]{visEvents},  \link[visNetwork]{visConfigure} ...
 #'
 #' @import htmlwidgets
 #' 
 #' @importFrom jsonlite fromJSON
 #'
 #' @export
-#' @references See online documentation \url{http://datastorm-open.github.io/visNetwork/}
+#' @references See online documentation \url{https://datastorm-open.github.io/visNetwork/}
 visNetwork <- function(nodes = NULL, edges = NULL, dot = NULL, gephi = NULL,
                        width = NULL, height = NULL, main = NULL, submain = NULL, 
                        footer = NULL, background = 'rgba(0, 0, 0, 0)', ...) {
@@ -247,6 +246,12 @@ visNetwork <- function(nodes = NULL, edges = NULL, dot = NULL, gephi = NULL,
     edgesToDataframe <- FALSE
   }
 
+  if(is.data.frame(nodes) & is.data.frame(edges)){
+    rm_edges <- which(!(edges$from %in% nodes$id & edges$to %in% nodes$id))
+    if(length(rm_edges) > 0){
+      edges <- edges[-c(rm_edges), ]
+    }
+  }
   # main
   if(!is.null(main)){
     if(is.list(main)){
@@ -370,4 +375,4 @@ visNetwork <- function(nodes = NULL, edges = NULL, dot = NULL, gephi = NULL,
     height = height,
     package = 'visNetwork'
   )
-}
\ No newline at end of file
+}
